import { useState, useEffect } from 'react';
export const defaultQueries = [
    '(min-width: 1400px)', '(min-width: 1200px)', '(min-width: 992px)', '(min-width: 768px)', '(min-width: 576px)'
];
export const isBrowser = typeof window !== "undefined" && window;
export const masonryQueries = [
    '(min-width: 1650px)', '(min-width: 1375px)', '(min-width: 1100px)', '(min-width: 825px)', '(min-width: 550px)'
];
export var Size;
(function (Size) {
    Size[Size["sm"] = 0] = "sm";
    Size[Size["md"] = 1] = "md";
    Size[Size["lg"] = 2] = "lg";
    Size[Size["xl"] = 3] = "xl";
    Size[Size["xxl"] = 4] = "xxl";
    Size[Size["fluid"] = 5] = "fluid";
})(Size || (Size = {}));
export var UiFunction;
(function (UiFunction) {
    UiFunction[UiFunction["None"] = 0] = "None";
    UiFunction[UiFunction["Primary"] = 1] = "Primary";
    UiFunction[UiFunction["Secondary"] = 2] = "Secondary";
    UiFunction[UiFunction["Success"] = 3] = "Success";
    UiFunction[UiFunction["Danger"] = 4] = "Danger";
    UiFunction[UiFunction["Warning"] = 5] = "Warning";
    UiFunction[UiFunction["Info"] = 6] = "Info";
    UiFunction[UiFunction["Light"] = 7] = "Light";
    UiFunction[UiFunction["Dark"] = 8] = "Dark";
    UiFunction[UiFunction["Link"] = 9] = "Link";
})(UiFunction || (UiFunction = {}));
export function useColumnSizes(size, colSpan) {
    const collapsedStyle = {
        flexShrink: 0
    };
    const expandedStyle = {
        flex: (colSpan > 0) ? '0 0 auto' : '1 0 auto',
        width: (colSpan > 0) ? (colSpan / 12) * 100 + '%' : 'auto',
    };
    switch (size) {
        case Size.fluid:
            return useMedia(defaultQueries, [collapsedStyle, collapsedStyle, collapsedStyle, collapsedStyle, collapsedStyle], collapsedStyle);
        case Size.xxl:
            return useMedia(defaultQueries, [expandedStyle, collapsedStyle, collapsedStyle, collapsedStyle, collapsedStyle], collapsedStyle);
        case Size.xl:
            return useMedia(defaultQueries, [expandedStyle, expandedStyle, collapsedStyle, collapsedStyle, collapsedStyle], collapsedStyle);
        case Size.lg:
            return useMedia(defaultQueries, [expandedStyle, expandedStyle, expandedStyle, collapsedStyle, collapsedStyle], collapsedStyle);
        case Size.md:
            return useMedia(defaultQueries, [expandedStyle, expandedStyle, expandedStyle, expandedStyle, collapsedStyle], collapsedStyle);
        default:
            return useMedia(defaultQueries, [expandedStyle, expandedStyle, expandedStyle, expandedStyle, expandedStyle], collapsedStyle);
    }
}
export function useContainerSizes(size) {
    switch (size) {
        case Size.fluid:
            return useMedia(defaultQueries, ['100%', '100%', '100%', '100%', '100%'], '100%');
        case Size.xxl:
            return useMedia(defaultQueries, ['1320px', '100%', '100%', '100%', '100%'], '100%');
        case Size.xl:
            return useMedia(defaultQueries, ['1320px', '1140px', '100%', '100%', '100%'], '100%');
        case Size.lg:
            return useMedia(defaultQueries, ['1320px', '1140px', '960px', '100%', '100%'], '100%');
        case Size.md:
            return useMedia(defaultQueries, ['1320px', '1140px', '960px', '720px', '100%'], '100%');
        default:
            return useMedia(defaultQueries, ['1320px', '1140px', '960px', '720px', '540px'], '100%');
    }
}
export function useMasonryColumns() {
    return useMedia(masonryQueries, [6, 5, 4, 3, 2], 1);
}
export function useMedia(queries, values, defaultValue) {
    if (!isBrowser)
        return defaultValue;
    const mediaQueryLists = queries.map((q) => window?.matchMedia(q));
    const getValue = () => {
        const index = mediaQueryLists.findIndex((mql) => mql.matches);
        return values?.[index] || defaultValue;
    };
    const [value, setValue] = useState(getValue);
    useEffect(() => {
        const handler = () => setValue(getValue);
        mediaQueryLists.forEach((mql) => mql.addEventListener("change", handler));
        return () => mediaQueryLists.forEach((mql) => mql.removeEventListener("change", handler));
    }, []);
    return value;
}
export function useWindowSize() {
    const [windowSize, setWindowSize] = useState({
        width: isBrowser ? window.innerWidth : 1200,
        height: isBrowser ? window.innerHeight : 800,
    });
    function changeWindowSize() {
        setWindowSize({ width: window.innerWidth, height: window.innerHeight });
    }
    useEffect(() => {
        window.addEventListener("resize", changeWindowSize);
        return () => { window.removeEventListener("resize", changeWindowSize); };
    }, []);
    return windowSize;
}
